### Changelog

All notable changes to this project will be documented in this file. Dates are displayed in UTC.

Generated by [`auto-changelog`](https://github.com/CookPete/auto-changelog).

#### [v0.0.3](https://github.com/connor-french/spaceprime/compare/v0.0.2...v0.0.3)

> 22 April 2024

- add analysis module black fix [`28ce742`](https://github.com/connor-french/spaceprime/commit/28ce7425ba04a5ba495192f85c561e2f37bd21f1)
- finish first round of utilities functions- black fix [`1b48527`](https://github.com/connor-french/spaceprime/commit/1b485270a595d0fa47629978ff69863e97d0fbf0)
- add demography module and associated package updates- black fixes [`b4e292e`](https://github.com/connor-french/spaceprime/commit/b4e292ea1716c7b1a22bdb09b2d8f3b207292826)
- black fix [`c9d8981`](https://github.com/connor-french/spaceprime/commit/c9d8981c441eb38711b0f8af66b66ff95f7d9a67)
- finish up utilities [`3a2daea`](https://github.com/connor-french/spaceprime/commit/3a2daea878995e4e012993fc73c88a2d872487cb)
- update documentation- black fix [`8f759de`](https://github.com/connor-french/spaceprime/commit/8f759de3fbd16aa01eb77fb503440c97c587fad0)
- reformat function based on black [`35b1d09`](https://github.com/connor-french/spaceprime/commit/35b1d093a1d2770ca166a7a06f9867c7395309af)
- fix some typing around integers- black fix [`7fbec2d`](https://github.com/connor-french/spaceprime/commit/7fbec2d9a3f491ffc4b73db556e395374c5fa3ac)
- add linting pre-commit hook [`40adedf`](https://github.com/connor-french/spaceprime/commit/40adedf1f8a2879604889880ed7d5339eb0ad330)
- more docs config [`83d26aa`](https://github.com/connor-french/spaceprime/commit/83d26aac7c377c7bc4db5bd5ab6da08664d78c57)
- clean up some files [`3a8f372`](https://github.com/connor-french/spaceprime/commit/3a8f3725e58709b4ca6872eb2ed317bfe73b4a92)
- debug demography functions black fix [`c575312`](https://github.com/connor-french/spaceprime/commit/c5753128dfd5168fc201648912ec972138e0c120)
- fix mkdocs spacing [`ba3973f`](https://github.com/connor-french/spaceprime/commit/ba3973f04661ca41311369d6641fe29de6a73432)
- remove common module [`c447ef5`](https://github.com/connor-french/spaceprime/commit/c447ef5faae1ae3e3584d82f2e055be4d5ae295c)
- clean up docs [`182cfbc`](https://github.com/connor-french/spaceprime/commit/182cfbc3570bdd49b3669d6ef0073768a0bc93bc)
- add transformation docs [`9c0dd29`](https://github.com/connor-french/spaceprime/commit/9c0dd292581e658c4c3cd3ca71f196358128b4ed)
- fix [`4ad0fd9`](https://github.com/connor-french/spaceprime/commit/4ad0fd9e4ee41acae3d7cadbdbc49bd6de5d31f1)
- Bump version: 0.0.2 → 0.0.3 [`70491b3`](https://github.com/connor-french/spaceprime/commit/70491b384d92f05962bf23069b57166011923418)
- black fix [`f2384e1`](https://github.com/connor-french/spaceprime/commit/f2384e1cf4d4eaa6d5d41df8850ded5c80bb52c6)
- fix tests and forgot to add requirements [`7ba1ef3`](https://github.com/connor-french/spaceprime/commit/7ba1ef39c323ca5381f864188357218c394fb3a7)
- figuring out docs [`753a6fe`](https://github.com/connor-french/spaceprime/commit/753a6fe75078f76c837605bbeb96b405c38e482f)
- fix index and move stuff around [`73fb2ac`](https://github.com/connor-french/spaceprime/commit/73fb2acdd29fef12caf0ffa14d38ab05738f921b)
- fix typo [`fea66dd`](https://github.com/connor-french/spaceprime/commit/fea66ddf233b2774a71ead698c4822cc634b7396)
- add pytest to ubuntu.yml [`9520751`](https://github.com/connor-french/spaceprime/commit/9520751f93067bfb8115f053d59d55fecfc52a4a)

#### [v0.0.2](https://github.com/connor-french/spaceprime/compare/v0.0.1...v0.0.2)

> 4 April 2024

- add package stuff [`8de8843`](https://github.com/connor-french/spaceprime/commit/8de88438d371db3724e8853f47682635ed52b7f4)
- Bump version: 0.0.1 → 0.0.2 [`43a7eb4`](https://github.com/connor-french/spaceprime/commit/43a7eb4b2552552ba804327ae9fb738fb3e06290)

#### v0.0.1

> 4 April 2024

- first commit [`e322482`](https://github.com/connor-french/spaceprime/commit/e3224827c30df0e60b1d75a176befd84b5e7b5fd)
